( cd boot ; rm -rf System.map )
( cd boot ; ln -sf System.map-ide-2.4.31 System.map )
( cd boot ; rm -rf config )
( cd boot ; ln -sf config-ide-2.4.31 config )
( cd boot ; rm -rf vmlinuz )
( cd boot ; ln -sf vmlinuz-ide-2.4.31 vmlinuz )
